@@ -3,8 +3,6 @@
 
 const { Clutter, GLib, Gio, St } = imports.gi;
 
-const Params = imports.misc.params;
-
 var ANIMATED_ICON_UPDATE_TIMEOUT = 16;
 var SPINNER_ANIMATION_TIME = 300;
 var SPINNER_ANIMATION_DELAY = 1000;
@@ -133,22 +131,12 @@ var AnimatedIcon = class extends Animation {
 };
 
 var Spinner = class extends AnimatedIcon {
-    constructor(size, params) {
-        // Compatibility with older callers
-        if (params === true || params === false)
-            params = { animate: params };
-
-        params = Params.parse(params, {
-            animate: false,
-            hideOnStop: false,
-        });
+    constructor(size, animate = false) {
         let file = Gio.File.new_for_uri('resource:///org/gnome/shell/theme/process-working.svg');
         super(file, size);
 
         this.actor.opacity = 0;
-        this._animate = params.animate;
-        this._hideOnStop = params.hideOnStop;
-        this.actor.visible = !this._hideOnStop;
+        this._animate = animate;
     }
 
     _onDestroy() {
@@ -158,7 +146,6 @@ var Spinner = class extends AnimatedIcon {
 
     play() {
         this.actor.remove_all_transitions();
-        this.actor.show();
 
         if (this._animate) {
             super.play();
@@ -182,18 +169,11 @@ var Spinner = class extends AnimatedIcon {
                 opacity: 0,
                 duration: SPINNER_ANIMATION_TIME,
                 mode: Clutter.AnimationMode.LINEAR,
-                onComplete: () => {
-                    super.stop();
-                    if (this._hideOnStop)
-                        this.actor.hide();
-                },
+                onComplete: () => super.stop()
             });
         } else {
             this.actor.opacity = 0;
             super.stop();
-
-            if (this._hideOnStop)
-                this.actor.hide();
         }
     }
 };
